# Introduction

Python library for footy.eu website.

Version 1.0 is deprecated. Please see USAGE

# TODO
- [X] Local team and Visiting team attribute
- [X] Division reference in Team
- [X] Generate calendar
- [X] Look for a calendar module that support unicode
- [ ] Tests..


